pub struct DCIUpdate {
pub new_entrypoints: HashMap<ComponentId, HashSet<EntryPoint>>,
pub new_entrypoint_params: HashMap<EntryPointId, HashSet<(TracingParams, ComponentId)>>,
pub trace_results: HashMap<EntryPointId, TracingResult>,
}Fields
new_entrypoints: HashMap<ComponentId, HashSet<EntryPoint>>new_entrypoint_params: HashMap<EntryPointId, HashSet<(TracingParams, ComponentId)>>trace_results: HashMap<EntryPointId, TracingResult>Trait Implementations
Sourceimpl DeepSizeOf for DCIUpdate
impl DeepSizeOf for DCIUpdate
Sourcefn deep_size_of_children(&self, context: &mut Context) -> usize
fn deep_size_of_children(&self, context: &mut Context) -> usize
Returns an estimation of the heap-managed storage of this object.
This does not include the size of the object itself. Read more
Sourcefn deep_size_of(&self) -> usize
fn deep_size_of(&self) -> usize
Returns an estimation of a total size of memory owned by the
object, including heap-managed storage. Read more
Sourceimpl<'de> Deserialize<'de> for DCIUpdate
impl<'de> Deserialize<'de> for DCIUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for DCIUpdate