pub struct TxInput { /* private fields */ }Expand description
Raw EVM transaction with its associated logs.
The succeeded flag allows callers to pass all transactions in a block and
have the processor skip reverted ones, avoiding a separate pre-filter.
Implementations
Sourceimpl TxInput
impl TxInput
pub fn new( hash: Bytes, from: Bytes, to: Bytes, index: u64, logs: Vec<LogInput>, succeeded: bool, ) -> Self
pub fn hash(&self) -> &Bytes
pub fn from(&self) -> &Bytes
pub fn to(&self) -> &Bytes
pub fn index(&self) -> u64
pub fn logs(&self) -> &[LogInput]
pub fn succeeded(&self) -> bool