pub struct TxWithContractChanges {
pub tx: Transaction,
pub contract_changes: AccountToContractChanges,
}Expand description
Storage changes grouped by transaction.
Fields
tx: Transactioncontract_changes: AccountToContractChangesTrait Implementations
Sourceimpl Clone for TxWithContractChanges
impl Clone for TxWithContractChanges
Sourcefn clone(&self) -> TxWithContractChanges
fn clone(&self) -> TxWithContractChanges
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TxWithContractChanges
impl Debug for TxWithContractChanges
Sourceimpl DeepSizeOf for TxWithContractChanges
impl DeepSizeOf for TxWithContractChanges
Sourcefn deep_size_of_children(&self, context: &mut Context) -> usize
fn deep_size_of_children(&self, context: &mut Context) -> usize
Returns an estimation of the heap-managed storage of this object.
This does not include the size of the object itself. Read more
Sourcefn deep_size_of(&self) -> usize
fn deep_size_of(&self) -> usize
Returns an estimation of a total size of memory owned by the
object, including heap-managed storage. Read more
Sourceimpl Default for TxWithContractChanges
impl Default for TxWithContractChanges
Sourcefn default() -> TxWithContractChanges
fn default() -> TxWithContractChanges
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for TxWithContractChanges
impl PartialEq for TxWithContractChanges
Sourcefn eq(&self, other: &TxWithContractChanges) -> bool
fn eq(&self, other: &TxWithContractChanges) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TxWithContractChanges