pub struct ProtocolComponent<Token: Into<Address> + Clone = Address> {
pub id: ComponentId,
pub protocol_system: String,
pub protocol_type_name: String,
pub chain: Chain,
pub tokens: Vec<Token>,
pub contract_addresses: Vec<Address>,
pub static_attributes: HashMap<AttrStoreKey, StoreVal>,
pub change: ChangeType,
pub creation_tx: TxHash,
pub created_at: NaiveDateTime,
}Expand description
ProtocolComponent provides detailed descriptions of a component of a protocol,
for example, swap pools that enables the exchange of two tokens.
A ProtocolComponent can be associated with an Account, and it has an identifier (id) that
can be either the on-chain address or a custom one. It belongs to a specific ProtocolSystem
and has a ProtocolTypeID that associates it with a ProtocolType that describes its behaviour
e.g., swap, lend, bridge. The component is associated with a specific Chain and holds
information about tradable tokens, related contract IDs, and static attributes.
Every values of a ProtocolComponent must be static, they can’t ever be changed after creation.
The dynamic values associated to a component must be given using ProtocolComponentState.
Fields
id: ComponentIdprotocol_system: Stringprotocol_type_name: Stringchain: Chaintokens: Vec<Token>contract_addresses: Vec<Address>static_attributes: HashMap<AttrStoreKey, StoreVal>change: ChangeTypecreation_tx: TxHashcreated_at: NaiveDateTimeImplementations
Sourceimpl<T> ProtocolComponent<T>
impl<T> ProtocolComponent<T>
pub fn new( id: &str, protocol_system: &str, protocol_type_name: &str, chain: Chain, tokens: Vec<T>, contract_addresses: Vec<Address>, static_attributes: HashMap<AttrStoreKey, StoreVal>, change: ChangeType, creation_tx: TxHash, created_at: NaiveDateTime, ) -> Self