TokenOwnerStore

Struct TokenOwnerStore 

pub struct TokenOwnerStore { /* private fields */ }
A store for tracking token owners and their balances.

The TokenOwnerStore maintains a mapping between token addresses and their respective owner’s address and balance. It can be used to quickly retrieve token owner information without needing to query external sources.

Implementations