pub struct MarginalPriceParams<'a> { /* private fields */ }Expand description
Parameters for querying the spot price between two tokens.
Used to get the current marginal price for infinitesimally small trades between two tokens in a pool.
Implementations
Sourceimpl<'a> MarginalPriceParams<'a>
impl<'a> MarginalPriceParams<'a>
Sourceimpl<'a> MarginalPriceParams<'a>
impl<'a> MarginalPriceParams<'a>
Sourcepub fn new(token_in: &'a TokenAddress, token_out: &'a TokenAddress) -> Self
pub fn new(token_in: &'a TokenAddress, token_out: &'a TokenAddress) -> Self
Creates new parameters for querying marginal price.
Arguments
token_in- The input token addresstoken_out- The output token address
pub fn token_in(&self) -> &TokenAddress
pub fn token_out(&self) -> &TokenAddress