pub struct SwapLimits { /* private fields */ }Expand description
Defines the trading limits for input and output amounts in a swap.
Specifies the minimum and maximum amounts that can be traded through a pool for both input and output tokens.
Implementations