pub struct Transition {}Expand description
Result of applying a state transition to a pool.
Currently, a placeholder struct that may be extended in the future to contain transition metadata or validation results.