pub enum SwapConstraint {
#[non_exhaustive] TradeLimitPrice {
limit: Price,
tolerance: f64,
min_amount_in: Option<BigUint>,
max_amount_in: Option<BigUint>,
},
#[non_exhaustive] PoolTargetPrice {
target: Price,
tolerance: f64,
min_amount_in: Option<BigUint>,
max_amount_in: Option<BigUint>,
},
}Expand description
Defines constraints for advanced quote calculations.
These constraints allow sophisticated trading strategies by limiting swaps based on price thresholds or targeting specific pool states.
Variants
#[non_exhaustive]TradeLimitPrice
This mode will calculate the maximum trade that this pool can execute while respecting a trade limit price.
Fields
This variant is marked as non-exhaustive
limit: PriceThe minimum acceptable price for the resulting trade, as a Price struct. The resulting amount_out / amount_in must be >= trade_limit_price
#[non_exhaustive]PoolTargetPrice
This mode will calculate the amount of token_in required to move the pool’s marginal price down to a target price, and the amount of token_out received.
Edge Cases and Limitations
Computing the exact amount to move a pool’s marginal price to a target has several challenges:
- The definition of marginal price varies between protocols. It is usually not an attribute of the pool but a consequence of its liquidity distribution and current state.
- For protocols with concentrated liquidity, the marginal price is discrete, meaning we can’t always find an exact trade amount to reach the target price.
- Not all protocols support analytical solutions for this problem, requiring numerical methods.
Fields
This variant is marked as non-exhaustive
target: PriceThe marginal price we want the pool to be after the trade, as a Price struct. The pool’s price will move down to this level as token_in is sold into it
Implementations
Sourceimpl SwapConstraint
impl SwapConstraint
Sourcepub fn trade_limit_price(limit: Price, tolerance: f64) -> Self
pub fn trade_limit_price(limit: Price, tolerance: f64) -> Self
Creates a trade limit price constraint.
This constraint finds the maximum trade size while respecting a minimum price
threshold. See SwapConstraint::TradeLimitPrice for details.
Arguments
limit- The minimum acceptable price for the tradetolerance- Additional tolerance as a fraction to loosen the constraint
Sourcepub fn pool_target_price(target: Price, tolerance: f64) -> Self
pub fn pool_target_price(target: Price, tolerance: f64) -> Self
Creates a pool target price constraint.
This constraint calculates the trade needed to move the pool’s price to a
target level. See SwapConstraint::PoolTargetPrice for details.`
Arguments
target- The desired final marginal price of the pooltolerance- Acceptable variance from the target price as a fraction
Sourcepub fn with_lower_bound(self, lower: BigUint) -> SimulationResult<Self>
pub fn with_lower_bound(self, lower: BigUint) -> SimulationResult<Self>
Sourcepub fn with_upper_bound(self, upper: BigUint) -> SimulationResult<Self>
pub fn with_upper_bound(self, upper: BigUint) -> SimulationResult<Self>