pub struct QuoteParams<'a> { /* private fields */ }Expand description
Parameters for requesting a swap quote from a pool.
Contains the tokens to swap between, the input amount, and whether the simulation should return a modified state to reflect the swap execution.
Implementations
Sourceimpl<'a> QuoteParams<'a>
impl<'a> QuoteParams<'a>
Sourceimpl<'a> QuoteParams<'a>
impl<'a> QuoteParams<'a>
Sourcepub fn fixed_in(
token_in: &'a TokenAddress,
token_out: &'a TokenAddress,
amount: BigUint,
) -> SimulationResult<Self>
pub fn fixed_in( token_in: &'a TokenAddress, token_out: &'a TokenAddress, amount: BigUint, ) -> SimulationResult<Self>
Creates new fixed input parameters with default settings (no state modification).
Arguments
token_in- The token to selltoken_out- The token to buyamount- The amount of input token to sell
Sourcepub fn fixed_out(
token_in: &'a TokenAddress,
token_out: &'a TokenAddress,
amount: BigUint,
) -> SimulationResult<Self>
pub fn fixed_out( token_in: &'a TokenAddress, token_out: &'a TokenAddress, amount: BigUint, ) -> SimulationResult<Self>
Creates new fixed output parameters with default settings (no state modification).
Arguments
token_in- The token to selltoken_out- The token to buyamount- The amount of output token to buy
pub fn amount(&self) -> &QuoteAmount
Sourcepub fn with_new_state(self) -> Self
pub fn with_new_state(self) -> Self
Configures the quote to modify the state during simulation.
When enabled, the quote simulation will return an updated state as if the swap was actually executed.
Sourcepub fn token_in(&self) -> &TokenAddress
pub fn token_in(&self) -> &TokenAddress
Returns the input token address.
Sourcepub fn token_out(&self) -> &TokenAddress
pub fn token_out(&self) -> &TokenAddress
Returns the output token address.
Sourcepub fn should_return_new_state(&self) -> bool
pub fn should_return_new_state(&self) -> bool
Returns whether the simulation should return the post-swap state.